==> haskell-stmonadtrans-0.4.8-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 STMonadTrans
version:              0.4.8
visibility:           public
id:                   STMonadTrans-0.4.8-4ALWQnVdTSzBbw8PY2nTV7
key:                  STMonadTrans-0.4.8-4ALWQnVdTSzBbw8PY2nTV7
license:              BSD-3-Clause
maintainer:           Andreas Abel, josef.svenningsson@gmail.com
author:               Josef Svenningsson
homepage:             https://github.com/josefs/STMonadTrans
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad.

    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  c170b77a1ddf2e5a37dc3de30560f908
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/STMonadTrans-0.4.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/STMonadTrans-0.4.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stmonadtrans
hs-libraries:         HSSTMonadTrans-0.4.8-4ALWQnVdTSzBbw8PY2nTV7
depends:
    array-0.5.4.0 base-4.16.4.0 mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.8-35.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 STMonadTrans
version:              0.4.8
visibility:           public
id:                   STMonadTrans-0.4.8-4pvamdshCi4HAppfo23UWI
key:                  STMonadTrans-0.4.8-4pvamdshCi4HAppfo23UWI
license:              BSD-3-Clause
maintainer:           Andreas Abel, josef.svenningsson@gmail.com
author:               Josef Svenningsson
homepage:             https://github.com/josefs/STMonadTrans
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad.

    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  d3d13efc2bd50d525e46b1b78e48a3c9
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stmonadtrans
hs-libraries:         HSSTMonadTrans-0.4.8-4pvamdshCi4HAppfo23UWI
depends:
    array-0.5.4.0 base-4.17.2.1 mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
